/**
 * Store.js - global app state.
 *
 * Part of the basebox sample TODO app.
 * https://basebox.tech
 */
import { reactive } from 'vue'

export const store = reactive({

  /** Username of the currently logged-in user */
  userName: "stranger",

  /** base URL of basebox broker host */
  baseboxHost: "http://127.0.0.1:8080",

  /** basebox session data */
  session: {},

  /** Fatal error message, if any */
  fatalError: "",

});

/**
 * Return true if the user is logged in.
 */
export function loggedIn() {
  return store.session && store.session.token;
}

/**
 * Clear session data.
 */
export function clearSession() {
  store.session = {};
}

/**
 * Show an error.
 */
export function showError(message) {
  store.fatalError = message;
}

/**
 * Clear error.
 */
export function clearError() {
  store.fatalError = "";
}
